package com.hw.dms.service;

import java.util.List;
import com.hw.dms.domain.DmsFaultInstanceFile;

/**
 * 故障文件;手工创建，从故障报修开始Service接口
 * 
 * @author Open Platform
 * @date 2024-02-29
 */
public interface IDmsFaultInstanceFileService 
{
    /**
     * 查询故障文件;手工创建，从故障报修开始
     * 
     * @param repairInstanceFileId 故障文件;手工创建，从故障报修开始主键
     * @return 故障文件;手工创建，从故障报修开始
     */
    public DmsFaultInstanceFile selectDmsFaultInstanceFileByRepairInstanceFileId(Long repairInstanceFileId);

    /**
     * 查询故障文件;手工创建，从故障报修开始列表
     * 
     * @param dmsFaultInstanceFile 故障文件;手工创建，从故障报修开始
     * @return 故障文件;手工创建，从故障报修开始集合
     */
    public List<DmsFaultInstanceFile> selectDmsFaultInstanceFileList(DmsFaultInstanceFile dmsFaultInstanceFile);

    /**
     * 新增故障文件;手工创建，从故障报修开始
     * 
     * @param dmsFaultInstanceFile 故障文件;手工创建，从故障报修开始
     * @return 结果
     */
    public int insertDmsFaultInstanceFile(DmsFaultInstanceFile dmsFaultInstanceFile);

    /**
     * 修改故障文件;手工创建，从故障报修开始
     * 
     * @param dmsFaultInstanceFile 故障文件;手工创建，从故障报修开始
     * @return 结果
     */
    public int updateDmsFaultInstanceFile(DmsFaultInstanceFile dmsFaultInstanceFile);

    /**
     * 批量删除故障文件;手工创建，从故障报修开始
     * 
     * @param repairInstanceFileIds 需要删除的故障文件;手工创建，从故障报修开始主键集合
     * @return 结果
     */
    public int deleteDmsFaultInstanceFileByRepairInstanceFileIds(Long[] repairInstanceFileIds);

    /**
     * 删除故障文件;手工创建，从故障报修开始信息
     * 
     * @param repairInstanceFileId 故障文件;手工创建，从故障报修开始主键
     * @return 结果
     */
    public int deleteDmsFaultInstanceFileByRepairInstanceFileId(Long repairInstanceFileId);
}
